@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.020-3-gb3746e0
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.021-4-ge3508dd
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -92,9 +92,6 @@ sub register_prereqs
 {
     my $self = shift;
 
-    # newer dzil renders META.json in ascii mode
-    return if eval { Dist::Zilla->VERSION('5.045'); 1 };
-
     return if none { /[^[:ascii:]]/ } @{ $self->_contributors };
 
     my $prereqs = $self->zilla->prereqs;
@@ -117,7 +114,11 @@ sub register_prereqs
     # perl, but we know that Dist::Zilla doesn't work until 5.8.7
     return if any { /^Dist::Zilla/ } keys %$all_prereqs;
 
-    # if dynamic_config is set, META.json will never be read so we're safe
+    # if dynamic_config is set, the user gets another chance to read the file, via fallback code:
+    # 22:44 < haarg> eumm loads META, updates prereqs, and writes out MYMETA
+    # 22:44 < haarg> so in a working system, x_contributors will be included
+    # 22:45 < haarg> in a broken system, it will fail to load META, regenerate it from parameters including META_ADD/MERGE, then write it out
+    # 22:46 < haarg> so if there isn't any utf8 data in the parameters given to EUMM, it will produce a file that can be read by a "bad" JSON::PP
     return if $self->zilla->distmeta->{dynamic_config};
 
     # see https://github.com/makamaka/JSON-PP/pull/9 for for details
@@ -262,7 +263,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
